@@ -1,5 +1,5 @@
-/* nfkc.c	Unicode normalization utilities.
- * Copyright (C) 2002, 2003  Simon Josefsson
+/* nfkc.c --- Unicode normalization utilities.
+ * Copyright (C) 2002, 2003, 2004  Simon Josefsson
  *
  * This file is part of GNU Libidn.
  *
@@ -51,7 +51,7 @@
 #define g_malloc malloc
 #define g_free free
 #define GError void
-#define g_set_error(a,b,c,d) 0
+#define g_set_error(a,b,c,d) ((void) 0)
 #define g_new(struct_type, n_structs)					\
   ((struct_type *) g_malloc (((gsize) sizeof (struct_type)) * ((gsize) (n_structs))))
 #  if defined (__GNUC__) && !defined (__STRICT_ANSI__) && !defined (__cplusplus)
@@ -169,7 +169,7 @@ static const gchar utf8_skip_data[256] = {
   5, 5, 5, 6, 6, 1, 1
 };
 
-const gchar *const g_utf8_skip = utf8_skip_data;
+static const gchar *const g_utf8_skip = utf8_skip_data;
 
 #define g_utf8_next_char(p) (char *)((p) + g_utf8_skip[*(guchar *)(p)])
 
